import testAll from './test-all';
/**
 * Informations sur le processeur.
 */
interface CpuInfo {
    /**
     * Le fabricant du processeur.
     * @type {string}
     */
    manufacturer: string;
    /**
     * La marque du processeur.
     * @type {string}
     */
    brand: string;
    /**
     * La vitesse du processeur en GHz.
     * @type {number}
     */
    speed: number;
    /**
     * Le nombre de cœurs logiques du processeur.
     * @type {number}
     */
    cores: number;
    /**
     * Le nombre de cœurs physiques du processeur.
     * @type {number}
     */
    physicalCores: number;
    /**
     * Le nombre de processeurs installés dans le système.
     * @type {number}
     */
    processors: number;
    /**
     * Les détails de chaque processeur.
     * @type {Array<CpuCoreInfo>}
     */
    coresInfo: CpuCoreInfo[];
}
/**
 * Informations sur chaque cœur du processeur.
 */
interface CpuCoreInfo {
    /**
     * Le nombre de cœurs logiques.
     * @type {number}
     */
    logicalCores?: number;
    /**
     * La fréquence du cœur en GHz.
     * @type {number}
     */
    frequency: number;
    /**
     * La charge du cœur en pourcentage.
     * @type {number}
     */
    load?: number;
}
/**
 * Informations sur la carte graphique.
 */
interface GpuInfo {
    /**
     * Le fabricant de la carte graphique.
     * @type {string}
     */
    manufacturer: string;
    /**
     * Le modèle de la carte graphique.
     * @type {string}
     */
    model: string;
    /**
     * La mémoire totale de la carte graphique en Mo.
     * @type {number}
     */
    memoryTotal: number;
    /**
     * La mémoire utilisée de la carte graphique en Mo.
     * @type {number}
     */
    memoryUsed: number;
    /**
     * La mémoire libre de la carte graphique en Mo.
     * @type {number}
     */
    memoryFree: number;
}
/**
 * Informations sur la mémoire RAM.
 */
interface RamInfo {
    /**
     * La mémoire totale du système en Go.
     * @type {number}
     */
    total: number;
    /**
     * La mémoire libre du système en Go.
     * @type {number}
     */
    free: number;
    /**
     * La mémoire utilisée du système en Go.
     * @type {number}
     */
    used: number;
}
/**
 * Informations sur le disque dur.
 */
interface DiskInfo {
    /**
     * La taille totale du disque en Go.
     * @type {number}
     */
    size: number;
    /**
     * L'espace utilisé du disque en Go.
     * @type {number}
     */
    used?: number;
    /**
     * L'espace libre du disque en Go.
     * @type {number}
     */
    free?: number;
    /**
     * Le type du disque (ex: SSD, HDD).
     * @type {string}
     */
    type: string;
}
/**
 * Informations sur le réseau.
 */
interface NetworkInfo {
    /**
     * La latence du réseau en millisecondes (ms).
     * @type {number}
     */
    speed: number;
    /**
     * L'interface réseau utilisée (ex: eth0, wlan0).
     * @type {string}
     */
    interface: string;
}
/**
 * Regroupe toutes les informations sur le système (processeur, carte graphique, mémoire, disque et réseau).
 */
interface SystemInfo {
    /**
     * Informations sur le processeur.
     * @type {CpuInfo}
     */
    cpu: CpuInfo;
    /**
     * Informations sur la carte graphique.
     * @type {GpuInfo}
     */
    gpu: GpuInfo;
    /**
     * Informations sur la RAM.
     * @type {RamInfo}
     */
    ram: RamInfo;
    /**
     * Informations sur le disque dur.
     * @type {DiskInfo}
     */
    disk: DiskInfo;
    /**
     * Informations sur le réseau.
     * @type {NetworkInfo}
     */
    network: NetworkInfo;
}
/**
 * Résultats des tests de performance des composants matériels.
 */
interface PerformanceTestResult {
    /**
     * La fréquence du processeur en GHz.
     * @type {number}
     */
    cpuFrequency: number;
    /**
     * La performance de la carte graphique (unité arbitraire).
     * @type {number}
     */
    gpuPerformance: number;
    /**
     * La vitesse de la RAM en Mo/s.
     * @type {number}
     */
    ramSpeed: number;
    /**
     * La vitesse du disque dur en Mo/s.
     * @type {number}
     */
    diskSpeed: number;
    /**
     * La performance du processeur en mode multithread (unité arbitraire).
     * @type {number}
     */
    multiThreadPerformance: number;
}
/**
 * Classe pour tester les performances du système et obtenir des informations système.
 */
declare class SystemTester {
    /**
     * Récupère les informations système détaillées telles que le processeur, la carte graphique, la RAM, le disque et le réseau.
     * @returns {Promise<SystemInfo>} Les informations système détaillées
     */
    static getSystemInfo(): Promise<SystemInfo>;
    /**
     * Teste la performance du processeur en mode multithread en utilisant plusieurs cœurs.
     * @returns {Promise<number>} La performance du processeur en multithread (unité arbitraire)
     */
    static testMultiThreadPerformance(): Promise<number>;
}
export { PerformanceTestResult, SystemTester, testAll };
